################################################################################################################################
#
# Description:	This constraint file applies to hardware features that are unique to a specific model number within a
#				product family.
#
# Rev History: 	07-14-2015:	Removed IDELAY group constraints that were required by the QDR MIG core that was removed.
# 				09-04-2013:	Inital release.
#
################################################################################################################################

###################################################### Timing Constraints ######################################################

# Set the RX1 clock frequency to 400 MHz (1.6 GHz ADC)
create_clock -period 2.500 -name rx_clk [get_ports rx1_clk_in_p]
set_clock_groups -name async_rx_clk -asynchronous -group [get_clocks rx_clk]

# Set a false path to the clock input buffer used for dynamic phase alignment.
set_false_path -through [get_pins {XCVR/RX_CH.ADC/CLK_FORWARD[1].CLK_DDR/D}]

###################################################### Pinout Constraints ######################################################
# Note: The external component and pin name connected to each PACKAGE_PIN is shown as a comment (#component:pin).

# RX1 pin assignments.
set_property PACKAGE_PIN AF24 [get_ports {rx1_data_in_p[0]}];  #ADC12D1600:DId[0]P
set_property PACKAGE_PIN AD26 [get_ports {rx1_data_in_p[1]}];  #ADC12D1600:DId[1]P
set_property PACKAGE_PIN AD25 [get_ports {rx1_data_in_p[2]}];  #ADC12D1600:DId[2]P
set_property PACKAGE_PIN AE23 [get_ports {rx1_data_in_p[3]}];  #ADC12D1600:DId[3]P
set_property PACKAGE_PIN AD21 [get_ports {rx1_data_in_p[4]}];  #ADC12D1600:DId[4]P
set_property PACKAGE_PIN AE22 [get_ports {rx1_data_in_p[5]}];  #ADC12D1600:DId[5]P
set_property PACKAGE_PIN AD23 [get_ports {rx1_data_in_p[6]}];  #ADC12D1600:DId[6]P
set_property PACKAGE_PIN AC23 [get_ports {rx1_data_in_p[7]}];  #ADC12D1600:DId[7]P
set_property PACKAGE_PIN Y22 [get_ports {rx1_data_in_p[8]}];  #ADC12D1600:DId[8]P
set_property PACKAGE_PIN AB22 [get_ports {rx1_data_in_p[9]}];  #ADC12D1600:DId[9]P
set_property PACKAGE_PIN W20 [get_ports {rx1_data_in_p[10]}];  #ADC12D1600:DId[10]P
set_property PACKAGE_PIN AB21 [get_ports {rx1_data_in_p[11]}];  #ADC12D1600:DId[11]P
set_property PACKAGE_PIN AA25 [get_ports {rx1_data_in_p[12]}];  #ADC12D1600:DI[0]P
set_property PACKAGE_PIN AB26 [get_ports {rx1_data_in_p[13]}];  #ADC12D1600:DI[1]P
set_property PACKAGE_PIN AA23 [get_ports {rx1_data_in_p[14]}];  #ADC12D1600:DI[2]P
set_property PACKAGE_PIN Y25 [get_ports {rx1_data_in_p[15]}];  #ADC12D1600:DI[3]P
set_property PACKAGE_PIN Y23 [get_ports {rx1_data_in_p[16]}];  #ADC12D1600:DI[4]P
set_property PACKAGE_PIN W23 [get_ports {rx1_data_in_p[17]}];  #ADC12D1600:DI[5]P
set_property PACKAGE_PIN W25 [get_ports {rx1_data_in_p[18]}];  #ADC12D1600:DI[6]P
set_property PACKAGE_PIN V23 [get_ports {rx1_data_in_p[19]}];  #ADC12D1600:DI[7]P
set_property PACKAGE_PIN V21 [get_ports {rx1_data_in_p[20]}];  #ADC12D1600:DI[8]P
set_property PACKAGE_PIN U26 [get_ports {rx1_data_in_p[21]}];  #ADC12D1600:DI[9]P
set_property PACKAGE_PIN U22 [get_ports {rx1_data_in_p[22]}];  #ADC12D1600:DI[10]P
set_property PACKAGE_PIN U24 [get_ports {rx1_data_in_p[23]}];  #ADC12D1600:DI[11]P
set_property PACKAGE_PIN H17 [get_ports rx1_ovr_in_p];  #ADC12D1600:ORIP
set_property PACKAGE_PIN G22 [get_ports rx1_clk_in_p];  #ADC12D1600:DCLKIP

# RX2 pin assignments.
set_property PACKAGE_PIN K25 [get_ports {rx2_data_in_p[0]}];  #ADC12D1600:DQd[0]P
set_property PACKAGE_PIN M25 [get_ports {rx2_data_in_p[1]}];  #ADC12D1600:DQd[1]P
set_property PACKAGE_PIN M24 [get_ports {rx2_data_in_p[2]}];  #ADC12D1600:DQd[2]P
set_property PACKAGE_PIN M21 [get_ports {rx2_data_in_p[3]}];  #ADC12D1600:DQd[3]P
set_property PACKAGE_PIN N26 [get_ports {rx2_data_in_p[4]}];  #ADC12D1600:DQd[4]P
set_property PACKAGE_PIN N19 [get_ports {rx2_data_in_p[5]}];  #ADC12D1600:DQd[5]P
set_property PACKAGE_PIN N21 [get_ports {rx2_data_in_p[6]}];  #ADC12D1600:DQd[6]P
set_property PACKAGE_PIN P24 [get_ports {rx2_data_in_p[7]}];  #ADC12D1600:DQd[7]P
set_property PACKAGE_PIN P23 [get_ports {rx2_data_in_p[8]}];  #ADC12D1600:DQd[8]P
set_property PACKAGE_PIN R25 [get_ports {rx2_data_in_p[9]}];  #ADC12D1600:DQd[9]P
set_property PACKAGE_PIN R26 [get_ports {rx2_data_in_p[10]}];  #ADC12D1600:DQd[10]P
set_property PACKAGE_PIN P19 [get_ports {rx2_data_in_p[11]}];  #ADC12D1600:DQd[11]P
set_property PACKAGE_PIN N18 [get_ports {rx2_data_in_p[12]}];  #ADC12D1600:DQ[0]P
set_property PACKAGE_PIN P16 [get_ports {rx2_data_in_p[13]}];  #ADC12D1600:DQ[1]P
set_property PACKAGE_PIN R18 [get_ports {rx2_data_in_p[14]}];  #ADC12D1600:DQ[2]P
set_property PACKAGE_PIN R22 [get_ports {rx2_data_in_p[15]}];  #ADC12D1600:DQ[3]P
set_property PACKAGE_PIN R21 [get_ports {rx2_data_in_p[16]}];  #ADC12D1600:DQ[4]P
set_property PACKAGE_PIN R16 [get_ports {rx2_data_in_p[17]}];  #ADC12D1600:DQ[5]P
set_property PACKAGE_PIN T20 [get_ports {rx2_data_in_p[18]}];  #ADC12D1600:DQ[6]P
set_property PACKAGE_PIN T22 [get_ports {rx2_data_in_p[19]}];  #ADC12D1600:DQ[7]P
set_property PACKAGE_PIN T18 [get_ports {rx2_data_in_p[20]}];  #ADC12D1600:DQ[8]P
set_property PACKAGE_PIN T24 [get_ports {rx2_data_in_p[21]}];  #ADC12D1600:DQ[9]P
set_property PACKAGE_PIN U17 [get_ports {rx2_data_in_p[22]}];  #ADC12D1600:DQ[10]P
set_property PACKAGE_PIN U19 [get_ports {rx2_data_in_p[23]}];  #ADC12D1600:DQ[11]P
set_property PACKAGE_PIN H19 [get_ports rx2_ovr_in_p];  #ADC12D1600:ORQP
set_property PACKAGE_PIN F17 [get_ports rx2_clk_in_p];  #ADC12D1600:DCLKQP

